Document title goes here

# Settings

Please provide a description of your sector
Preview

Colour scheme
  The colours you select here apply only for the client side of the application. Try to pick colours that have high enough contrast to keep the text on each button legible.

  Please use the colour pickers below to select your organisation's colours. It's best to use a darker colour for the main colour and a lighter colour for the support colour.

  Main colour:
  Support colour:
Logo
  The logo will appear on both the client side app that your user group will see as well as on this editor environment in the top left corner. The new logo will only become visible after you've saved your changes.'
  Which logo you would like to display in the top left corner?
  - Europäische Agentur für
    Sicherheit und Gesundheitsschutz
    am Arbeitsplatz
  - My own:

  You may get the best results if you upload a logo as a transparent PNG file of at least 110 pixels in height. Uploading larger images is fine, the logo will be scaled down to the right size automatically.

User name & password
  This is the password that you need to log on to this editor environment.
  Username New password Repeat password
Contact person
  Lorem ipsum dolor sit amet.
  Contact name Contact e-mail address

- Surveys
- Documentation
- Sectors
- OiRA
- Search

### Survey versions

Survey 2010

- Current / Published January 4 2009 Preview Edit

Survey 2009

- Current December 12 2009 Preview Edit
- Published August 5 2009 Preview Edit Update
- March 18 2009 Preview Edit
- February 2 2009 Preview Edit
- January 28 2009 Preview Edit

##### Legend

- Current Version that is currently online
- Current Version you are currently reviewing

Update = This version has changes that are currently unpublished. Click the update icon to bring all the changes live

Draft

Leave retracted Published
Write a revision note.
Notify

Link to sector organisation | Disclaimer | Design by Cornae